@@ -98,7 +98,7 @@ def text2edges(text,verbose = False, verbose_text= False,include_otherEdge = Fal
     text1 = re.sub(r'\b' + art.capitalize() + r'\b'," ", text1)
   for token in nlp(text1):
     if token.pos_ == "NUM":
-      text1 = re.sub(r'\b' + token.text + r'\b',"  pengy  ", text1)  # space in case make new compund 
+      text1 = re.sub(r'\b' + token.text + r'\b',"    ", text1)  # space in case make new compund 
   for td in nounDEL:
     text1 =  re.sub(r'\b' + td + r'\b',"  ,  ", text1) 
     text1 =  re.sub(r'\b' + td.capitalize() + r'\b'," ,  ", text1) 
@@ -537,7 +537,7 @@ def target2edges(text,verbose = False, verbose_text= False,include_otherEdge = F
     text1 = re.sub(r'\b' + art.capitalize() + r'\b'," ", text1)
   for token in nlp(text1):
     if token.pos_ == "NUM":
-      text1 = re.sub(r'\b' + token.text + r'\b',"  pengy  ", text1)  # space in case make new compund 
+      text1 = re.sub(r'\b' + token.text + r'\b',"   ", text1)  # space in case make new compund 
   for td in nounDEL:
     text1 =  re.sub(r'\b' + td + r'\b',"  ,  ", text1) 
     text1 =  re.sub(r'\b' + td.capitalize() + r'\b'," ,  ", text1) 
